@@ -19,6 +19,7 @@ import requests
 from aigpy.progressHelper import ProgressTool
 from aigpy.convertHelper import convertStorageUnit
 from aigpy.pathHelper import getFileName
+import ssl
 
 def downloadString(url, timeouts=(3.05, 27)):
     try:
@@ -76,17 +77,22 @@ def downloadFile(url, fileName, stimeout=None, showprogress=False, append=False)
     check, errmsg = downloadFileRetErr(url, fileName, stimeout, showprogress, append)
     return check
 
-def downloadFileRetErr(url, fileName, stimeout=None, showprogress=False, append=False):
+
+def downloadFileRetErr(url, fileName, stimeout=None, showprogress=False, append=False, ignoreCertificate = False):
     if sys.version_info > (3,0):
         from urllib.request import urlopen
     else:
         from urllib2 import urlopen
     
     try:
+        content = None
+        if ignoreCertificate:
+            content = ssl._create_unverified_context()
+
         if stimeout is None:
-            response = urlopen(url)
+            response = urlopen(url, context=content)
         else:
-            response = urlopen(url, timeout=stimeout)
+            response = urlopen(url, timeout=stimeout, context=content)
         
         unit = 'mb'
         if convertStorageUnit(response.length, 'byte', unit) < 1:
@@ -141,3 +147,5 @@ def getResult(code=0,msg='',data=''):
     ret['data']   = data
     return json.dumps(ret)
 
+
+
