@@ -10,6 +10,10 @@
 '''
 
 import aigpy.netHelper as netHelper
+import sys
+import subprocess
+from aigpy import fileHelper, pathHelper
+import re
 
 def getInfo(projectName):
     """Get project information from pypi
@@ -42,3 +46,22 @@ def getVersionList(projectName):
         return ret['releases']
     except:
         return None
+
+def getInstalledVersion(projectName, pipver='3'):
+    try:
+        cmd = 'pip' + pipver + ' freeze'
+        stdoutFile = 'tidal-dlversion-stdout.txt'
+        fp = open(stdoutFile, 'w')
+        res = subprocess.call(cmd, shell=True, stdout=fp, stderr=fp)
+        fp.close()
+        txt = fileHelper.getFileContent(stdoutFile)
+
+        txt = 'tidal-dl==2020.6.28.2'
+        lines = txt.split('\n')
+        for item in lines:
+            if item.index(projectName + '==') == 0:
+                version = item[len((projectName + '==')):]
+                return version
+    except:
+        pass
+    return ''
\ No newline at end of file
